@@ -1,6 +1,5 @@
 import textwrap
 import re
-import inspect
 
 from oelint_parser.const_func import KNOWN_FUNCS
 from oelint_parser.const_vars import get_known_machines
@@ -42,6 +41,10 @@ class Item():
         """
         return self.__Line
 
+    @Line.setter
+    def Line(self, value):
+        self.__Line = value
+    
     @property
     def Raw(self):
         """Raw string (without inline code blocks)
@@ -214,11 +217,17 @@ class Item():
         Returns:
             dict -- all public attributes and their values
         """
+        T = type(self)
         res = {}
-        classes = inspect.getmembers(self, inspect.isclass)
-        for cls in classes:
-            for x in inspect.getmembers(cls[1], lambda o: isinstance(o, property)):
-                res[x[0]] = x[1].fget(self)
+        for _ in dir(self):
+            try:
+                attr = getattr(T, _)
+            except AttributeError:
+                continue  # Skip dunder attributes, i.e. private attributes
+            else:
+                if isinstance(attr, property):
+                    res[_] = getattr(self, _)
+
         return res
 
     def __repr__(self):
@@ -475,6 +484,53 @@ class Include(Item):
         """
         return [self.IncName, self.Statement]
 
+class Export(Item):
+    CLASSIFIER = "Exclude"
+    ATTR_INCNAME = "Name"
+    ATTR_STATEMENT = "Value"
+
+    def __init__(self, origin, line, infileline, rawtext, name, value, realraw):
+        """constructor
+
+        Arguments:
+            origin {str} -- Full path to file of origin
+            line {int} -- Overall line counter
+            infileline {int} -- Line counter in the particular file
+            rawtext {str} -- Raw input string (except inline code blocks)
+            realraw {str} -- Unprocessed input
+            name {str} -- variable name of the export
+            value {str} -- (optional) value of the export
+        """
+        super().__init__(origin, line, infileline, rawtext, realraw)
+        self.__Name = name
+        self.__Value = value
+
+    @property
+    def Name(self):
+        """Name of the exported var
+
+        Returns:
+            str: name of the exported var
+        """
+        return self.__Name
+
+    @property
+    def Value(self):
+        """value of the export
+
+        Returns:
+            str: optional value of the export
+        """
+        return self.__Value
+
+    def get_items(self):
+        """Get items
+
+        Returns:
+            list -- include name, include statement
+        """
+        return [self.Name, self.Value]
+
 
 class Function(Item):
     ATTR_FUNCNAME = "FuncName"
